Comando Linux od

Linux 命令大全Manual completo de comandos Linux

El comando Linux od se utiliza para mostrar el contenido de archivos.

La instrucción od lee el contenido del archivo proporcionado y lo presenta en código octal.

Sintaxis

od [-abcdfhilovx][-A <字码基数>][-j <字符数目>][-N <字符数目>][-s <字符串字符数>][-t <输出格式>][-w <每列字符数>][--help][--version][文件...]

Parámetros:

  • -a  El efecto de este parámetro es el mismo que especificar el parámetro "-ta" al mismo tiempo.
  • -A<base>  Selecciona la base para calcular los códigos.
  • -b  El efecto de este parámetro es el mismo que especificar el parámetro "-toC" al mismo tiempo.
  • -c  El efecto de este parámetro es el mismo que especificar el parámetro "-tC" al mismo tiempo.
  • -d  El efecto de este parámetro es el mismo que especificar el parámetro "-tu2" al mismo tiempo.
  • -f  El efecto de este parámetro es el mismo que especificar el parámetro "-tfF" al mismo tiempo.
  • -h  El efecto de este parámetro es el mismo que especificar el parámetro "-tx2" al mismo tiempo.
  • -i  El efecto de este parámetro es el mismo que especificar el parámetro "-td2" al mismo tiempo.
  • -j<número de caracteres> o --skip-bytes=<número de caracteres>  Omite el número de caracteres configurado.
  • -l  El efecto de este parámetro es el mismo que especificar el parámetro "-td4" al mismo tiempo.
  • -N<número de caracteres> o --read-bytes=<número de caracteres>  Hasta el número de caracteres configurado.
  • -o  El efecto de este parámetro es el mismo que especificar el parámetro "-to2" al mismo tiempo.
  • -s<número de caracteres de cadena> o --strings=<número de caracteres de cadena>  Muestra solo las cadenas que coinciden con el número de caracteres especificado.
  • -t<formato de salida> o --format=<formato de salida>  Establece el formato de salida.
  • -v o --output-duplicates  No omite datos duplicados al generar la salida.
  • -w<número de caracteres por columna> o --width=<número de caracteres por columna>  Establece el número máximo de caracteres por columna.
  • -x  El efecto de este parámetro es el mismo que especificar el parámetro "-h" al mismo tiempo.
  • --help  Ayuda en línea.
  • --version  Muestra información de la versión.

Ejemplos

Crear un archivo tmp:

$ echo abcdef g > tmp
$ cat tmp
abcdef g

Usar el comando od:

$ od -b tmp
0000000 141 142 143 144 145 146 040 147 012
0000011

Usa la interpretación octal de un solo byte para la salida; observa que el formato de dirección predeterminado a la izquierda es octal:

$ od -c tmp
0000000   a   b   c   d   e   f       g  \n
0000011

Usa el código ASCII para la salida; observa que incluye caracteres de escape.

$ od -t d1 tmp
0000000   97   98   99  100  101  102   32  103   10
0000011

Interpreta en decimal de un solo byte.

$ od -A d -c tmp
0000000   a   b   c   d   e   f       g  \n
0000009

Linux 命令大全Manual completo de comandos Linux

Otras extensiones